@@ -497,7 +497,7 @@ pub mod private {
 	#[cfg(feature = "database")]
 	pub use gotham_middleware_diesel::Repo;
 	#[cfg(feature = "openapi")]
-	pub use openapi_type::{indexmap::IndexMap, openapi, OpenapiSchema, OpenapiType};
+	pub use openapi_type::{OpenapiSchema, OpenapiType, Visitor};
 }
 
 #[cfg(feature = "auth")]
@@ -524,8 +524,8 @@ pub use endpoint::{Endpoint, NoopExtractor};
 
 mod response;
 pub use response::{
-	AuthError, AuthError::Forbidden, AuthErrorOrOther, AuthResult, AuthSuccess, IntoResponse,
-	IntoResponseError, NoContent, Raw, Redirect, Response, Success
+	AuthError, AuthErrorOrOther, AuthResult, AuthSuccess, IntoResponse, IntoResponseError,
+	NoContent, Raw, Redirect, Response, Success
 };
 #[cfg(feature = "openapi")]
 pub use response::{IntoResponseWithSchema, ResponseSchema};
